Sorting, Searching, and Counting
================================

.. https://docs.scipy.org/doc/numpy/reference/routines.sort.html

Sorting
-------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.sort
   cupy.lexsort
   cupy.argsort
   cupy.msort
   cupy.sort_complex
   cupy.partition
   cupy.argpartition

.. seealso::
   :func:`cupy.ndarray.sort`

Searching
---------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.argmax
   cupy.nanargmax
   cupy.argmin
   cupy.nanargmin
   cupy.nonzero
   cupy.flatnonzero
   cupy.where
   cupy.argwhere

Counting
--------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.count_nonzero
